<?php

namespace Drupal\uw_cfg_common\Commands;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\uw_cfg_common\UwRoles\UwRoles;
use Drush\Commands\DrushCommands;

/**
 * Drush commands for uw_cfg_common module.
 *
 * @package Drupal\uw_cfg_common\Commands
 */
class UwDrushCommands extends DrushCommands {

  /**
   * Entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * {@inheritDoc}
   */
  public function __construct(EntityTypeManagerInterface $entityTypeManager) {
    $this->entityTypeManager = $entityTypeManager;
  }

  /**
   * Drush command to set permissions to what is in user role yml files.
   *
   * Yml files are located: /src/UwRoles. This command will only set
   * permissions to what is in the yml file. It will not remove any
   * permission. To remove a permission you need an update hook as well as
   * remove it from the yml file.
   *
   * @command uw:permissions
   * @aliases uwperm
   * @usage uwperm
   */
  public function updatePermissions() {

    // Get all the role ids in the system.
    $rids = UwRoles::getAllRoles();

    // Step through each rid and set the permissions.
    foreach ($rids as $rid) {

      // Get the info about the role.
      $uw_role = UwRoles::getUwRole($rid);

      // Set the permissions for the role.
      UwRoles::setUwPermissions($uw_role);

      // Set message for specific role setting permissions.
      $this->logger()->success('Permissions set for ' . $uw_role['label'] . '.');
    }

    // Set message for command completed.
    $this->logger()->success('All permissions set.');
  }

}
